==> wpewebkit_2.38.6.orig.tar.xz: wpewebkit-2.38.6/Source/WebCore/PAL/pal/FileSizeFormatter.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "FileSizeFormatter.h"

#include <wtf/text/StringConcatenateNumbers.h>

namespace PAL {

#if !PLATFORM(COCOA)

AtomString fileSizeDescription(uint64_t size)
{
    // FIXME: These strings should be localized, but that would require bringing LocalizedStrings into PAL.
    // See <https://bugs.webkit.org/show_bug.cgi?id=179019> for more details.
    if (size < 1000)
        return makeAtomString(size, " bytes");
    if (size < 1000000)
        return makeAtomString(FormattedNumber::fixedWidth(size / 1000., 1), " KB");
    if (size < 1000000000)
        return makeAtomString(FormattedNumber::fixedWidth(size / 1000000., 1), " MB");
    return makeAtomString(FormattedNumber::fixedWidth(size / 1000000000., 1), " GB");
}

#endif

} // namespace PAL

==> wpewebkit_2.50.1.orig.tar.xz: wpewebkit-2.50.1/Source/WebCore/PAL/pal/FileSizeFormatter.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "FileSizeFormatter.h"

#include <wtf/text/MakeString.h>

namespace PAL {

#if !PLATFORM(COCOA)

AtomString fileSizeDescription(uint64_t size)
{
    // FIXME: These strings should be localized, but that would require bringing LocalizedStrings into PAL.
    // See <https://bugs.webkit.org/show_bug.cgi?id=179019> for more details.
    if (size < 1000)
        return makeAtomString(size, " bytes"_s);
    if (size < 1000000)
        return makeAtomString(FormattedNumber::fixedWidth(size / 1000., 1), " KB"_s);
    if (size < 1000000000)
        return makeAtomString(FormattedNumber::fixedWidth(size / 1000000., 1), " MB"_s);
    return makeAtomString(FormattedNumber::fixedWidth(size / 1000000000., 1), " GB"_s);
}

#endif

} // namespace PAL
